import { resolve, join } from 'path';
import { existsSync, rmdirSync, mkdirSync, readdirSync, copyFileSync } from 'fs';
import 'vue';
export { computed, createComponent, createElement, getCurrentInstance, inject, isRef, onActivated, onBeforeMount, onBeforeUnmount, onBeforeUpdate, onDeactivated, onErrorCaptured, onMounted, onServerPrefetch, onUnmounted, onUpdated, provide, reactive, ref, set, toRefs, watch, watchEffect } from '@vue/composition-api';
export { defineComponent, setSSRContext, shallowSsrRef, ssrRef, useAsync, useContext, useFetch, useMeta, useStatic, withContext } from './entrypoint.js';
import 'defu';

const compositionApiModule = function () {
    var _a;
    const libRoot = resolve(__dirname, '..');
    let corejsPolyfill;
    try {
        // eslint-disable-next-line
        const corejsPkg = require('core-js/package.json');
        corejsPolyfill = corejsPkg.version.slice(0, 1);
    }
    catch (_b) {
        corejsPolyfill = undefined;
    }
    const { dst: pluginDst } = this.addTemplate({
        src: resolve(libRoot, 'lib', 'plugin.js'),
        fileName: join('composition-api', 'plugin.js'),
        options: {
            corejsPolyfill,
        },
    });
    const staticPath = join(this.options.buildDir || '', 'static-json');
    this.nuxt.hook('build:compile', () => {
        if (existsSync(staticPath))
            rmdirSync(staticPath);
        mkdirSync(staticPath);
    });
    this.nuxt.hook('generate:done', async (generator) => {
        const srcDir = join(this.options.buildDir || '', 'static-json');
        const { distPath } = generator;
        readdirSync(srcDir).forEach(file => copyFileSync(join(srcDir, file), join(distPath, file)));
    });
    const { dst: entryDst } = this.addTemplate({
        src: resolve(libRoot, 'lib', 'entrypoint.js'),
        fileName: join('composition-api', 'index.js'),
        options: {
            staticPath,
            publicPath: join(((_a = this.options.router) === null || _a === void 0 ? void 0 : _a.base) || '', '/'),
        },
    });
    this.options.build = this.options.build || {};
    this.options.build.babel = this.options.build.babel || {};
    this.options.build.babel.plugins = this.options.build.babel.plugins || [];
    this.options.build.babel.plugins.push(join(__dirname, 'babel'));
    this.extendBuild(config => {
        config.resolve = config.resolve || {};
        config.resolve.alias = config.resolve.alias || {};
        config.resolve.alias['nuxt-composition-api'] = resolve(this.options.buildDir || '', entryDst);
    });
    this.options.plugins = this.options.plugins || [];
    this.options.plugins.unshift(resolve(this.options.buildDir || '', pluginDst));
};
// eslint-disable-next-line
const meta = require('../package.json');

export default compositionApiModule;
export { meta };
